@@ -22,7 +22,11 @@ class PyodbcConnection(resource.Resource[pyodbc.Connection]):
 
         self._handle: typing.Optional[pyodbc.Connection] = None
 
-    def open(self) -> pyodbc.Connection:
+    @staticmethod
+    def key() -> str:
+        return PyodbcConnection.__name__
+
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> pyodbc.Connection:
         if self._handle is None:
             self._handle = pyodbc.connect(
                 self._db_uri,
@@ -37,10 +41,6 @@ class PyodbcConnection(resource.Resource[pyodbc.Connection]):
             self._handle.close()
             self._handle = None
 
-    @classmethod
-    def interface(cls) -> typing.Type[PyodbcConnection]:
-        return PyodbcConnection
-
     def rollback(self) -> None:
         if self._handle is not None:
             self._handle.rollback()
@@ -51,6 +51,6 @@ class PyodbcConnection(resource.Resource[pyodbc.Connection]):
                 "Attempted to call save() on a read-only connection."
             )
         if self._handle is None:
-            raise exceptions.ResourceClosed()
+            raise exceptions.SharedResourceManagerClosed()
         else:
             self._handle.commit()
