@@ -21,22 +21,22 @@ class PyodbcCursor(resource.Resource[pyodbc.Cursor]):
 
         self._handle: typing.Optional[pyodbc.Cursor] = None
 
+    @staticmethod
+    def key() -> str:
+        return PyodbcCursor.__name__
+
     def close(self) -> None:
         if self._handle is not None:
             self._handle.close()
             self._handle = None
 
-    def open(self) -> pyodbc.Cursor:
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> pyodbc.Cursor:
         if self._handle is None:
             self._handle = self._con.cursor()
             self._handle.fast_executemany = self._fast_executemany
             # self._handle.setinputsizes([(pyodbc.SQL_WVARCHAR, 0, 0)])
         return self._handle
 
-    @classmethod
-    def interface(cls) -> typing.Type[PyodbcCursor]:
-        return PyodbcCursor
-
     def rollback(self) -> None:
         if self._handle is not None:
             self._handle.rollback()
