@@ -30,6 +30,10 @@ class DummyRepository(repository.Repository[E], abc.ABC, typing.Generic[E]):
 
         self.events: typing.List[typing.Tuple[str, typing.Dict[str, typing.Any]]] = []
 
+    @staticmethod
+    def key() -> str:
+        return DummyRepository.__name__
+
     def rollback(self) -> None:
         self.events.append(("rollback", {}))
         self._current_state = self._previous_state.copy()
@@ -63,7 +67,7 @@ class DummyRepository(repository.Repository[E], abc.ABC, typing.Generic[E]):
         self.events.append(("delete_all", {}))
         self._current_state = []
 
-    def open(self) -> repository.Repository[E]:
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> repository.Repository[E]:
         return typing.cast(repository.Repository[E], self)
 
     def set_all(self, items: typing.Collection[E], /) -> typing.Collection[E]:
