@@ -18,6 +18,11 @@ class Repository(
 ):
     """Interface to access elements of a collection"""
 
+    @staticmethod
+    @abc.abstractmethod
+    def key() -> str:
+        raise NotImplementedError
+
     @abc.abstractmethod
     def add(self, /, item: E) -> E:
         raise NotImplementedError
@@ -38,7 +43,7 @@ class Repository(
     def delete_all(self) -> None:
         raise NotImplementedError
 
-    def open(self) -> Repository[E]:
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> Repository[E]:
         return self
 
     @abc.abstractmethod
