@@ -37,6 +37,10 @@ class TempFileSharedResource(resource.Resource[typing.IO[bytes]]):
         self.close()
         return False
 
+    @staticmethod
+    def key() -> str:
+        return TempFileSharedResource.__name__
+
     def clear(self) -> None:
         self.handle.seek(0, 0)  # go to beginning of file
         self.handle.truncate()
@@ -51,17 +55,13 @@ class TempFileSharedResource(resource.Resource[typing.IO[bytes]]):
             self.open()
         return self._file_handle  # type: ignore
 
-    @classmethod
-    def interface(cls) -> typing.Type[TempFileSharedResource]:
-        return cls
-
     @property
     def file_path(self) -> pathlib.Path:
         if self._file_path is None:
             self._file_path = pathlib.Path(self.handle.name)
         return self._file_path
 
-    def open(self) -> typing.IO[bytes]:
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> typing.IO[bytes]:
         ext = f".{self._file_extension}" if self._file_extension else None
         self._file_handle = tempfile.NamedTemporaryFile(
             prefix=self._prefix,
