@@ -11,6 +11,7 @@ __all__ = (
 )
 
 T = typing.TypeVar("T")
+R = typing.TypeVar("R", bound=resource.Resource[typing.Any])
 
 
 class SharedResourceManager:
@@ -22,10 +23,8 @@ class SharedResourceManager:
         resource.check_for_ambiguous_implementations(shared_resource)
 
         self.__shared_resources: typing.Dict[str, resource.Resource[typing.Any]] = {
-            r.interface().__name__: r for r in shared_resource
+            r.key(): r for r in shared_resource
         }
-        # self.__shared_resources = tuple(shared_resource)
-        self.__handles: typing.Dict[str, typing.Any] = {}
         self.__opened = False
         self.__closed = False
 
@@ -33,7 +32,7 @@ class SharedResourceManager:
         if self.__opened:
             raise exceptions.ResourcesAlreadyOpen()
         if self.__closed:
-            raise exceptions.ResourceClosed()
+            raise exceptions.SharedResourceManagerClosed()
         self.__opened = True
         return self
 
@@ -48,36 +47,33 @@ class SharedResourceManager:
 
     def close(self):
         if self.__closed:
-            raise exceptions.ResourceClosed()
-        for resource_name in self.__handles.keys():
+            raise exceptions.SharedResourceManagerClosed()
+        for resource_name in self.__shared_resources.keys():
             self.__shared_resources[resource_name].close()
-        self.__handles = {}
         self.__closed = True
         self.__opened = False
 
-    def exists(self, /, resource_type: typing.Type[resource.Resource[T]]) -> bool:
-        return resource_type.__name__ in self.__shared_resources.keys()
+    def exists(self, /, key: str) -> bool:
+        return key in self.__shared_resources.keys()
 
     def get(
-        self,
-        resource_type: typing.Type[resource.Resource[T]],
-    ) -> T:
+        self, resource_type: typing.Type[R], *, key: typing.Optional[str] = None
+    ) -> R:
+        if key is None:
+            try:
+                key = resource_type.key()
+            except NotImplementedError:
+                raise exceptions.ResourceHasNoKey(resource_name=resource_type.__name__)
+
         if self.__closed:
-            raise exceptions.ResourceClosed()
-        elif (
-            interface_name := resource_type.interface().__name__
-        ) in self.__handles.keys():
-            return self.__handles[interface_name]
-        elif interface_name in self.__shared_resources.keys():
-            r = self.__shared_resources[interface_name]
-            handle = r.open()
-            self.__handles[interface_name] = handle
-            return handle
+            raise exceptions.SharedResourceManagerClosed()
+        elif key in self.__shared_resources.keys():
+            r = self.__shared_resources[key]
         else:
             raise exceptions.MissingResourceError(
-                resource_name=interface_name,
-                available_resources=self.__shared_resources.keys(),
+                key=key, available_resources=self.__shared_resources.keys()
             )
+        return typing.cast(R, r)
 
     def __eq__(self, other: object) -> bool:
         if other.__class__ is self.__class__:
