@@ -15,14 +15,14 @@ class SqlAlchemyEngine(resource.Resource[sa.engine.Engine]):
         self._db_uri = db_uri
         self._engine: typing.Optional[sa.engine.Engine] = None
 
+    @staticmethod
+    def key() -> str:
+        return SqlAlchemyEngine.__name__
+
     def transaction(self) -> sqlalchemy_transaction.SqlAlchemyTransaction:
         return sqlalchemy_transaction.SqlAlchemyTransaction(self._engine)
 
-    def open(self) -> sa.engine.Engine:
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> sa.engine.Engine:
         if self._engine is None:
             self._engine = sa.create_engine(self._db_uri)
         return self._engine
-
-    @classmethod
-    def interface(cls) -> typing.Type[SqlAlchemyEngine]:
-        return SqlAlchemyEngine
