@@ -6,7 +6,6 @@ from sqlalchemy import orm
 
 from lime_uow import exceptions, resource
 
-
 __all__ = ("SqlAlchemySession",)
 
 
@@ -15,11 +14,11 @@ class SqlAlchemySession(resource.Resource[orm.Session]):
         self._session_factory = session_factory
         self._session: typing.Optional[orm.Session] = None
 
-    @classmethod
-    def interface(cls) -> typing.Type[SqlAlchemySession]:
-        return cls
+    @staticmethod
+    def key() -> str:
+        return SqlAlchemySession.__name__
 
-    def open(self) -> orm.Session:
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> orm.Session:
         self._session = self._session_factory()
         return self._session
 
