@@ -14,7 +14,11 @@ class SqlAlchemyTransaction(resource.Resource[sa.engine.Transaction]):
         self._engine = engine
         self._transaction: typing.Optional[sa.engine.Transaction] = None
 
-    def open(self) -> sa.engine.Transaction:
+    @staticmethod
+    def key() -> str:
+        return SqlAlchemyTransaction.__name__
+
+    def open(self, **kwargs: typing.Dict[str, typing.Any]) -> sa.engine.Transaction:
         if self._transaction is None:
             self._transaction = self._engine.begin()
         return self._transaction
@@ -24,10 +28,6 @@ class SqlAlchemyTransaction(resource.Resource[sa.engine.Transaction]):
             self._transaction.close()
             self._transaction = None
 
-    @classmethod
-    def interface(cls) -> typing.Type[SqlAlchemyTransaction]:
-        return SqlAlchemyTransaction
-
     def rollback(self) -> None:
         if self._transaction is not None:
             self._transaction.rollback()
